@@ -92,7 +92,12 @@ class ScriptEditor(QWidget):
         _exec_code(self._code_edit.toPlainText(), self._viewer)
 
     def set_code(self, code):
-        self._code_edit.setPlainText(code)
+        if self._code_edit.toPlainText() != code:
+            cursor_position = self._code_edit.textCursor().position()
+            self._code_edit.setPlainText(code)
+            cursor = self._code_edit.textCursor()
+            cursor.setPosition(cursor_position)
+            self._code_edit.setTextCursor(cursor)
 
     @classmethod
     def _add_script_editor(cls, instance):
